/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtGui.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"

#line 98 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 30 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qtransform.sip"
#include <qtransform.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 164 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 41 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
#include <qpainterpath.h>
#line 47 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 329 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpolygon.sip"
#include <qpolygon.h>
#line 50 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 53 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 56 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 59 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 62 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"


PyDoc_STRVAR(doc_QPainterPath_closeSubpath, "closeSubpath(self)");

extern "C" {static PyObject *meth_QPainterPath_closeSubpath(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_closeSubpath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            sipCpp->closeSubpath();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_closeSubpath, doc_QPainterPath_closeSubpath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_moveTo, "moveTo(self, Union[QPointF, QPoint])\n"
"moveTo(self, float, float)");

extern "C" {static PyObject *meth_QPainterPath_moveTo(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_moveTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPointF* a0;
        int a0State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->moveTo(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1))
        {
            sipCpp->moveTo(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_moveTo, doc_QPainterPath_moveTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_lineTo, "lineTo(self, Union[QPointF, QPoint])\n"
"lineTo(self, float, float)");

extern "C" {static PyObject *meth_QPainterPath_lineTo(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_lineTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPointF* a0;
        int a0State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->lineTo(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1))
        {
            sipCpp->lineTo(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_lineTo, doc_QPainterPath_lineTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_arcTo, "arcTo(self, QRectF, float, float)\n"
"arcTo(self, float, float, float, float, float, float)");

extern "C" {static PyObject *meth_QPainterPath_arcTo(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_arcTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
         ::qreal a1;
         ::qreal a2;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9dd", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0, &a1, &a2))
        {
            sipCpp->arcTo(*a0,a1,a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::qreal a4;
         ::qreal a5;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddddd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->arcTo(a0,a1,a2,a3,a4,a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_arcTo, doc_QPainterPath_arcTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_cubicTo, "cubicTo(self, Union[QPointF, QPoint], Union[QPointF, QPoint], Union[QPointF, QPoint])\n"
"cubicTo(self, float, float, float, float, float, float)");

extern "C" {static PyObject *meth_QPainterPath_cubicTo(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_cubicTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QPointF* a1;
        int a1State = 0;
        const  ::QPointF* a2;
        int a2State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1J1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State, sipType_QPointF, &a2, &a2State))
        {
            sipCpp->cubicTo(*a0,*a1,*a2);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1),sipType_QPointF,a1State);
            sipReleaseType(const_cast< ::QPointF *>(a2),sipType_QPointF,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::qreal a4;
         ::qreal a5;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddddd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5))
        {
            sipCpp->cubicTo(a0,a1,a2,a3,a4,a5);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_cubicTo, doc_QPainterPath_cubicTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_quadTo, "quadTo(self, Union[QPointF, QPoint], Union[QPointF, QPoint])\n"
"quadTo(self, float, float, float, float)");

extern "C" {static PyObject *meth_QPainterPath_quadTo(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_quadTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QPointF* a1;
        int a1State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QPointF, &a1, &a1State))
        {
            sipCpp->quadTo(*a0,*a1);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);
            sipReleaseType(const_cast< ::QPointF *>(a1),sipType_QPointF,a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->quadTo(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_quadTo, doc_QPainterPath_quadTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_currentPosition, "currentPosition(self) -> QPointF");

extern "C" {static PyObject *meth_QPainterPath_currentPosition(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_currentPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::QPointF*sipRes;

            sipRes = new  ::QPointF(sipCpp->currentPosition());

            return sipConvertFromNewType(sipRes,sipType_QPointF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_currentPosition, doc_QPainterPath_currentPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addRect, "addRect(self, QRectF)\n"
"addRect(self, float, float, float, float)");

extern "C" {static PyObject *meth_QPainterPath_addRect(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->addRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->addRect(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addRect, doc_QPainterPath_addRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addEllipse, "addEllipse(self, QRectF)\n"
"addEllipse(self, float, float, float, float)\n"
"addEllipse(self, Union[QPointF, QPoint], float, float)");

extern "C" {static PyObject *meth_QPainterPath_addEllipse(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addEllipse(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0))
        {
            sipCpp->addEllipse(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdddd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3))
        {
            sipCpp->addEllipse(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
         ::qreal a1;
         ::qreal a2;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1dd", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State, &a1, &a2))
        {
            sipCpp->addEllipse(*a0,a1,a2);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addEllipse, doc_QPainterPath_addEllipse);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addPolygon, "addPolygon(self, QPolygonF)");

extern "C" {static PyObject *meth_QPainterPath_addPolygon(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addPolygon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPolygonF* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPolygonF, &a0))
        {
            sipCpp->addPolygon(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addPolygon, doc_QPainterPath_addPolygon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addText, "addText(self, Union[QPointF, QPoint], QFont, str)\n"
"addText(self, float, float, QFont, str)");

extern "C" {static PyObject *meth_QPainterPath_addText(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QFont* a1;
        const  ::QString* a2;
        int a2State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9J1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State, sipType_QFont, &a1, sipType_QString,&a2, &a2State))
        {
            sipCpp->addText(*a0,*a1,*a2);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);
            sipReleaseType(const_cast< ::QString *>(a2),sipType_QString,a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
        const  ::QFont* a2;
        const  ::QString* a3;
        int a3State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BddJ9J1", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, sipType_QFont, &a2, sipType_QString,&a3, &a3State))
        {
            sipCpp->addText(a0,a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addText, doc_QPainterPath_addText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addPath, "addPath(self, QPainterPath)");

extern "C" {static PyObject *meth_QPainterPath_addPath(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
            sipCpp->addPath(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addPath, doc_QPainterPath_addPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addRegion, "addRegion(self, QRegion)");

extern "C" {static PyObject *meth_QPainterPath_addRegion(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addRegion(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRegion* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRegion, &a0))
        {
            sipCpp->addRegion(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addRegion, doc_QPainterPath_addRegion);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_connectPath, "connectPath(self, QPainterPath)");

extern "C" {static PyObject *meth_QPainterPath_connectPath(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_connectPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
            sipCpp->connectPath(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_connectPath, doc_QPainterPath_connectPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_contains, "contains(self, Union[QPointF, QPoint]) -> bool\n"
"contains(self, QRectF) -> bool\n"
"contains(self, QPainterPath) -> bool");

extern "C" {static PyObject *meth_QPainterPath_contains(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_contains(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QRectF* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QPainterPath* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->contains(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_contains, doc_QPainterPath_contains);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_intersects, "intersects(self, QRectF) -> bool\n"
"intersects(self, QPainterPath) -> bool");

extern "C" {static PyObject *meth_QPainterPath_intersects(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_intersects(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->intersects(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    {
        const  ::QPainterPath* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->intersects(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_intersects, doc_QPainterPath_intersects);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_boundingRect, "boundingRect(self) -> QRectF");

extern "C" {static PyObject *meth_QPainterPath_boundingRect(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_boundingRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::QRectF*sipRes;

            sipRes = new  ::QRectF(sipCpp->boundingRect());

            return sipConvertFromNewType(sipRes,sipType_QRectF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_boundingRect, doc_QPainterPath_boundingRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_controlPointRect, "controlPointRect(self) -> QRectF");

extern "C" {static PyObject *meth_QPainterPath_controlPointRect(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_controlPointRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::QRectF*sipRes;

            sipRes = new  ::QRectF(sipCpp->controlPointRect());

            return sipConvertFromNewType(sipRes,sipType_QRectF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_controlPointRect, doc_QPainterPath_controlPointRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_fillRule, "fillRule(self) -> Qt.FillRule");

extern "C" {static PyObject *meth_QPainterPath_fillRule(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_fillRule(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::Qt::FillRule sipRes;

            sipRes = sipCpp->fillRule();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_Qt_FillRule);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_fillRule, doc_QPainterPath_fillRule);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_setFillRule, "setFillRule(self, Qt.FillRule)");

extern "C" {static PyObject *meth_QPainterPath_setFillRule(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_setFillRule(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::FillRule a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_Qt_FillRule, &a0))
        {
            sipCpp->setFillRule(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_setFillRule, doc_QPainterPath_setFillRule);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_toReversed, "toReversed(self) -> QPainterPath");

extern "C" {static PyObject *meth_QPainterPath_toReversed(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_toReversed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->toReversed());

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_toReversed, doc_QPainterPath_toReversed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_toSubpathPolygons, "toSubpathPolygons(self) -> List[QPolygonF]\n"
"toSubpathPolygons(self, QTransform) -> List[QPolygonF]");

extern "C" {static PyObject *meth_QPainterPath_toSubpathPolygons(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_toSubpathPolygons(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            QList< ::QPolygonF>*sipRes = 0;

#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
        sipRes = new QList<QPolygonF>(sipCpp->toSubpathPolygons());
#line 892 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"

            return sipConvertFromNewType(sipRes,sipType_QList_0100QPolygonF,SIP_NULLPTR);
        }
    }

    {
        const  ::QTransform* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QTransform, &a0))
        {
            QList< ::QPolygonF>*sipRes;

            sipRes = new QList< ::QPolygonF>(sipCpp->toSubpathPolygons(*a0));

            return sipConvertFromNewType(sipRes,sipType_QList_0100QPolygonF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_toSubpathPolygons, doc_QPainterPath_toSubpathPolygons);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_toFillPolygons, "toFillPolygons(self) -> List[QPolygonF]\n"
"toFillPolygons(self, QTransform) -> List[QPolygonF]");

extern "C" {static PyObject *meth_QPainterPath_toFillPolygons(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_toFillPolygons(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            QList< ::QPolygonF>*sipRes = 0;

#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
        sipRes = new QList<QPolygonF>(sipCpp->toFillPolygons());
#line 937 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"

            return sipConvertFromNewType(sipRes,sipType_QList_0100QPolygonF,SIP_NULLPTR);
        }
    }

    {
        const  ::QTransform* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QTransform, &a0))
        {
            QList< ::QPolygonF>*sipRes;

            sipRes = new QList< ::QPolygonF>(sipCpp->toFillPolygons(*a0));

            return sipConvertFromNewType(sipRes,sipType_QList_0100QPolygonF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_toFillPolygons, doc_QPainterPath_toFillPolygons);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_toFillPolygon, "toFillPolygon(self) -> QPolygonF\n"
"toFillPolygon(self, QTransform) -> QPolygonF");

extern "C" {static PyObject *meth_QPainterPath_toFillPolygon(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_toFillPolygon(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::QPolygonF*sipRes = 0;

#line 94 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtGui/qpainterpath.sip"
        sipRes = new QPolygonF(sipCpp->toFillPolygon());
#line 982 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtGui/sipQtGuiQPainterPath.cpp"

            return sipConvertFromNewType(sipRes,sipType_QPolygonF,SIP_NULLPTR);
        }
    }

    {
        const  ::QTransform* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QTransform, &a0))
        {
             ::QPolygonF*sipRes;

            sipRes = new  ::QPolygonF(sipCpp->toFillPolygon(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPolygonF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_toFillPolygon, doc_QPainterPath_toFillPolygon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_arcMoveTo, "arcMoveTo(self, QRectF, float)\n"
"arcMoveTo(self, float, float, float, float, float)");

extern "C" {static PyObject *meth_QPainterPath_arcMoveTo(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_arcMoveTo(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
         ::qreal a1;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9d", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0, &a1))
        {
            sipCpp->arcMoveTo(*a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::qreal a4;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bddddd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3, &a4))
        {
            sipCpp->arcMoveTo(a0,a1,a2,a3,a4);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_arcMoveTo, doc_QPainterPath_arcMoveTo);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_isEmpty, "isEmpty(self) -> bool");

extern "C" {static PyObject *meth_QPainterPath_isEmpty(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_isEmpty(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isEmpty();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_isEmpty, doc_QPainterPath_isEmpty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_elementCount, "elementCount(self) -> int");

extern "C" {static PyObject *meth_QPainterPath_elementCount(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_elementCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->elementCount();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_elementCount, doc_QPainterPath_elementCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_elementAt, "elementAt(self, int) -> QPainterPath.Element");

extern "C" {static PyObject *meth_QPainterPath_elementAt(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_elementAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPainterPath, &sipCpp, &a0))
        {
             ::QPainterPath::Element*sipRes;

            sipRes = new  ::QPainterPath::Element(sipCpp->elementAt(a0));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath_Element,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_elementAt, doc_QPainterPath_elementAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_setElementPositionAt, "setElementPositionAt(self, int, float, float)");

extern "C" {static PyObject *meth_QPainterPath_setElementPositionAt(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_setElementPositionAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::qreal a1;
         ::qreal a2;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bidd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->setElementPositionAt(a0,a1,a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_setElementPositionAt, doc_QPainterPath_setElementPositionAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_length, "length(self) -> float");

extern "C" {static PyObject *meth_QPainterPath_length(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_length(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::qreal sipRes;

            sipRes = sipCpp->length();

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_length, doc_QPainterPath_length);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_percentAtLength, "percentAtLength(self, float) -> float");

extern "C" {static PyObject *meth_QPainterPath_percentAtLength(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_percentAtLength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0))
        {
             ::qreal sipRes;

            sipRes = sipCpp->percentAtLength(a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_percentAtLength, doc_QPainterPath_percentAtLength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_pointAtPercent, "pointAtPercent(self, float) -> QPointF");

extern "C" {static PyObject *meth_QPainterPath_pointAtPercent(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_pointAtPercent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0))
        {
             ::QPointF*sipRes;

            sipRes = new  ::QPointF(sipCpp->pointAtPercent(a0));

            return sipConvertFromNewType(sipRes,sipType_QPointF,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_pointAtPercent, doc_QPainterPath_pointAtPercent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_angleAtPercent, "angleAtPercent(self, float) -> float");

extern "C" {static PyObject *meth_QPainterPath_angleAtPercent(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_angleAtPercent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0))
        {
             ::qreal sipRes;

            sipRes = sipCpp->angleAtPercent(a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_angleAtPercent, doc_QPainterPath_angleAtPercent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_slopeAtPercent, "slopeAtPercent(self, float) -> float");

extern "C" {static PyObject *meth_QPainterPath_slopeAtPercent(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_slopeAtPercent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0))
        {
             ::qreal sipRes;

            sipRes = sipCpp->slopeAtPercent(a0);

            return PyFloat_FromDouble(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_slopeAtPercent, doc_QPainterPath_slopeAtPercent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_united, "united(self, QPainterPath) -> QPainterPath");

extern "C" {static PyObject *meth_QPainterPath_united(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_united(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->united(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_united, doc_QPainterPath_united);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_intersected, "intersected(self, QPainterPath) -> QPainterPath");

extern "C" {static PyObject *meth_QPainterPath_intersected(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_intersected(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->intersected(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_intersected, doc_QPainterPath_intersected);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_subtracted, "subtracted(self, QPainterPath) -> QPainterPath");

extern "C" {static PyObject *meth_QPainterPath_subtracted(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_subtracted(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->subtracted(*a0));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_subtracted, doc_QPainterPath_subtracted);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_addRoundedRect, "addRoundedRect(self, QRectF, float, float, mode: Qt.SizeMode = Qt.AbsoluteSize)\n"
"addRoundedRect(self, float, float, float, float, float, float, mode: Qt.SizeMode = Qt.AbsoluteSize)");

extern "C" {static PyObject *meth_QPainterPath_addRoundedRect(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_addRoundedRect(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QRectF* a0;
         ::qreal a1;
         ::qreal a2;
         ::Qt::SizeMode a3 = Qt::AbsoluteSize;
         ::QPainterPath *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9dd|E", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QRectF, &a0, &a1, &a2, sipType_Qt_SizeMode, &a3))
        {
            sipCpp->addRoundedRect(*a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::qreal a0;
         ::qreal a1;
         ::qreal a2;
         ::qreal a3;
         ::qreal a4;
         ::qreal a5;
         ::Qt::SizeMode a6 = Qt::AbsoluteSize;
         ::QPainterPath *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_mode,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bdddddd|E", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1, &a2, &a3, &a4, &a5, sipType_Qt_SizeMode, &a6))
        {
            sipCpp->addRoundedRect(a0,a1,a2,a3,a4,a5,a6);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_addRoundedRect, doc_QPainterPath_addRoundedRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_simplified, "simplified(self) -> QPainterPath");

extern "C" {static PyObject *meth_QPainterPath_simplified(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_simplified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->simplified());

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_simplified, doc_QPainterPath_simplified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_translate, "translate(self, float, float)\n"
"translate(self, Union[QPointF, QPoint])");

extern "C" {static PyObject *meth_QPainterPath_translate(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_translate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::qreal a1;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1))
        {
            sipCpp->translate(a0,a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
            sipCpp->translate(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_translate, doc_QPainterPath_translate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_translated, "translated(self, float, float) -> QPainterPath\n"
"translated(self, Union[QPointF, QPoint]) -> QPainterPath");

extern "C" {static PyObject *meth_QPainterPath_translated(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_translated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::qreal a0;
         ::qreal a1;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bdd", &sipSelf, sipType_QPainterPath, &sipCpp, &a0, &a1))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->translated(a0,a1));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPointF, &a0, &a0State))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath(sipCpp->translated(*a0));
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_translated, doc_QPainterPath_translated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_swap, "swap(self, QPainterPath)");

extern "C" {static PyObject *meth_QPainterPath_swap(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_swap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath* a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QPainterPath, &sipCpp, sipType_QPainterPath, &a0))
        {
            sipCpp->swap(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_swap, doc_QPainterPath_swap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_clear, "clear(self)");

extern "C" {static PyObject *meth_QPainterPath_clear(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_clear, doc_QPainterPath_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_reserve, "reserve(self, int)");

extern "C" {static PyObject *meth_QPainterPath_reserve(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_reserve(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
         ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QPainterPath, &sipCpp, &a0))
        {
            sipCpp->reserve(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_reserve, doc_QPainterPath_reserve);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QPainterPath_capacity, "capacity(self) -> int");

extern "C" {static PyObject *meth_QPainterPath_capacity(PyObject *, PyObject *);}
static PyObject *meth_QPainterPath_capacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QPainterPath, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->capacity();

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QPainterPath, sipName_capacity, doc_QPainterPath_capacity);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *slot_QPainterPath___mul__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___mul__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;
        const  ::QTransform* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPainterPath, &a0, sipType_QTransform, &a1))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath((*a0 * *a1));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, mul_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainterPath___isub__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___isub__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainterPath)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QPainterPath *sipCpp = reinterpret_cast< ::QPainterPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QPainterPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPainterPath, &a0))
        {
            sipCpp-> ::QPainterPath::operator-=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainterPath___iadd__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___iadd__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainterPath)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QPainterPath *sipCpp = reinterpret_cast< ::QPainterPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QPainterPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPainterPath, &a0))
        {
            sipCpp-> ::QPainterPath::operator+=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainterPath___ior__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___ior__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainterPath)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QPainterPath *sipCpp = reinterpret_cast< ::QPainterPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QPainterPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPainterPath, &a0))
        {
            sipCpp-> ::QPainterPath::operator|=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainterPath___iand__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___iand__(PyObject *sipSelf,PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QPainterPath)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

     ::QPainterPath *sipCpp = reinterpret_cast< ::QPainterPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QPainterPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPainterPath, &a0))
        {
            sipCpp-> ::QPainterPath::operator&=(*a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QPainterPath___sub__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___sub__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath* a0;
        const  ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPainterPath, &a0, sipType_QPainterPath, &a1))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath((*a0 - *a1));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, sub_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainterPath___add__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___add__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath* a0;
        const  ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPainterPath, &a0, sipType_QPainterPath, &a1))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath((*a0 + *a1));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, add_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainterPath___or__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___or__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath* a0;
        const  ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPainterPath, &a0, sipType_QPainterPath, &a1))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath((*a0 | *a1));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainterPath___and__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___and__(PyObject *sipArg0,PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QPainterPath* a0;
        const  ::QPainterPath* a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J9J9", sipType_QPainterPath, &a0, sipType_QPainterPath, &a1))
        {
             ::QPainterPath*sipRes;

            sipRes = new  ::QPainterPath((*a0 & *a1));

            return sipConvertFromNewType(sipRes,sipType_QPainterPath,SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QPainterPath___ne__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___ne__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QPainterPath *sipCpp = reinterpret_cast< ::QPainterPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QPainterPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPainterPath, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QPainterPath::operator!=(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, ne_slot, sipType_QPainterPath, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QPainterPath___eq__(PyObject *,PyObject *);}
static PyObject *slot_QPainterPath___eq__(PyObject *sipSelf,PyObject *sipArg)
{
     ::QPainterPath *sipCpp = reinterpret_cast< ::QPainterPath *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf,sipType_QPainterPath));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QPainterPath* a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J9", sipType_QPainterPath, &a0))
        {
            bool sipRes;

            sipRes = sipCpp-> ::QPainterPath::operator==(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtGui, eq_slot, sipType_QPainterPath, sipSelf, sipArg);
}


/* Call the instance's destructor. */
extern "C" {static void release_QPainterPath(void *, int);}
static void release_QPainterPath(void *sipCppV, int)
{
    delete reinterpret_cast< ::QPainterPath *>(sipCppV);
}


extern "C" {static void *array_QPainterPath(Py_ssize_t);}
static void *array_QPainterPath(Py_ssize_t sipNrElem)
{
    return new  ::QPainterPath[sipNrElem];
}


extern "C" {static void assign_QPainterPath(void *, SIP_SSIZE_T, void *);}
static void assign_QPainterPath(void *sipDst, SIP_SSIZE_T sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QPainterPath *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QPainterPath *>(sipSrc);
}


extern "C" {static void *copy_QPainterPath(const void *, SIP_SSIZE_T);}
static void *copy_QPainterPath(const void *sipSrc, SIP_SSIZE_T sipSrcIdx)
{
    return new  ::QPainterPath(reinterpret_cast<const  ::QPainterPath *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QPainterPath(sipSimpleWrapper *);}
static void dealloc_QPainterPath(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QPainterPath(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QPainterPath(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QPainterPath(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
     ::QPainterPath *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new  ::QPainterPath();

            return sipCpp;
        }
    }

    {
        const  ::QPointF* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QPointF, &a0, &a0State))
        {
            sipCpp = new  ::QPainterPath(*a0);
            sipReleaseType(const_cast< ::QPointF *>(a0),sipType_QPointF,a0State);

            return sipCpp;
        }
    }

    {
        const  ::QPainterPath* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QPainterPath, &a0))
        {
            sipCpp = new  ::QPainterPath(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QPainterPath[] = {
    {(void *)slot_QPainterPath___mul__, mul_slot},
    {(void *)slot_QPainterPath___isub__, isub_slot},
    {(void *)slot_QPainterPath___iadd__, iadd_slot},
    {(void *)slot_QPainterPath___ior__, ior_slot},
    {(void *)slot_QPainterPath___iand__, iand_slot},
    {(void *)slot_QPainterPath___sub__, sub_slot},
    {(void *)slot_QPainterPath___add__, add_slot},
    {(void *)slot_QPainterPath___or__, or_slot},
    {(void *)slot_QPainterPath___and__, and_slot},
    {(void *)slot_QPainterPath___ne__, ne_slot},
    {(void *)slot_QPainterPath___eq__, eq_slot},
    {0, (sipPySlotType)0}
};


static PyMethodDef methods_QPainterPath[] = {
    {SIP_MLNAME_CAST(sipName_addEllipse), meth_QPainterPath_addEllipse, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_addEllipse)},
    {SIP_MLNAME_CAST(sipName_addPath), meth_QPainterPath_addPath, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_addPath)},
    {SIP_MLNAME_CAST(sipName_addPolygon), meth_QPainterPath_addPolygon, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_addPolygon)},
    {SIP_MLNAME_CAST(sipName_addRect), meth_QPainterPath_addRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_addRect)},
    {SIP_MLNAME_CAST(sipName_addRegion), meth_QPainterPath_addRegion, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_addRegion)},
    {SIP_MLNAME_CAST(sipName_addRoundedRect), SIP_MLMETH_CAST(meth_QPainterPath_addRoundedRect), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QPainterPath_addRoundedRect)},
    {SIP_MLNAME_CAST(sipName_addText), meth_QPainterPath_addText, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_addText)},
    {SIP_MLNAME_CAST(sipName_angleAtPercent), meth_QPainterPath_angleAtPercent, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_angleAtPercent)},
    {SIP_MLNAME_CAST(sipName_arcMoveTo), meth_QPainterPath_arcMoveTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_arcMoveTo)},
    {SIP_MLNAME_CAST(sipName_arcTo), meth_QPainterPath_arcTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_arcTo)},
    {SIP_MLNAME_CAST(sipName_boundingRect), meth_QPainterPath_boundingRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_boundingRect)},
    {SIP_MLNAME_CAST(sipName_capacity), meth_QPainterPath_capacity, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_capacity)},
    {SIP_MLNAME_CAST(sipName_clear), meth_QPainterPath_clear, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_clear)},
    {SIP_MLNAME_CAST(sipName_closeSubpath), meth_QPainterPath_closeSubpath, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_closeSubpath)},
    {SIP_MLNAME_CAST(sipName_connectPath), meth_QPainterPath_connectPath, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_connectPath)},
    {SIP_MLNAME_CAST(sipName_contains), meth_QPainterPath_contains, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_contains)},
    {SIP_MLNAME_CAST(sipName_controlPointRect), meth_QPainterPath_controlPointRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_controlPointRect)},
    {SIP_MLNAME_CAST(sipName_cubicTo), meth_QPainterPath_cubicTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_cubicTo)},
    {SIP_MLNAME_CAST(sipName_currentPosition), meth_QPainterPath_currentPosition, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_currentPosition)},
    {SIP_MLNAME_CAST(sipName_elementAt), meth_QPainterPath_elementAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_elementAt)},
    {SIP_MLNAME_CAST(sipName_elementCount), meth_QPainterPath_elementCount, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_elementCount)},
    {SIP_MLNAME_CAST(sipName_fillRule), meth_QPainterPath_fillRule, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_fillRule)},
    {SIP_MLNAME_CAST(sipName_intersected), meth_QPainterPath_intersected, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_intersected)},
    {SIP_MLNAME_CAST(sipName_intersects), meth_QPainterPath_intersects, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_intersects)},
    {SIP_MLNAME_CAST(sipName_isEmpty), meth_QPainterPath_isEmpty, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_isEmpty)},
    {SIP_MLNAME_CAST(sipName_length), meth_QPainterPath_length, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_length)},
    {SIP_MLNAME_CAST(sipName_lineTo), meth_QPainterPath_lineTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_lineTo)},
    {SIP_MLNAME_CAST(sipName_moveTo), meth_QPainterPath_moveTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_moveTo)},
    {SIP_MLNAME_CAST(sipName_percentAtLength), meth_QPainterPath_percentAtLength, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_percentAtLength)},
    {SIP_MLNAME_CAST(sipName_pointAtPercent), meth_QPainterPath_pointAtPercent, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_pointAtPercent)},
    {SIP_MLNAME_CAST(sipName_quadTo), meth_QPainterPath_quadTo, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_quadTo)},
    {SIP_MLNAME_CAST(sipName_reserve), meth_QPainterPath_reserve, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_reserve)},
    {SIP_MLNAME_CAST(sipName_setElementPositionAt), meth_QPainterPath_setElementPositionAt, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_setElementPositionAt)},
    {SIP_MLNAME_CAST(sipName_setFillRule), meth_QPainterPath_setFillRule, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_setFillRule)},
    {SIP_MLNAME_CAST(sipName_simplified), meth_QPainterPath_simplified, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_simplified)},
    {SIP_MLNAME_CAST(sipName_slopeAtPercent), meth_QPainterPath_slopeAtPercent, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_slopeAtPercent)},
    {SIP_MLNAME_CAST(sipName_subtracted), meth_QPainterPath_subtracted, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_subtracted)},
    {SIP_MLNAME_CAST(sipName_swap), meth_QPainterPath_swap, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_swap)},
    {SIP_MLNAME_CAST(sipName_toFillPolygon), meth_QPainterPath_toFillPolygon, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_toFillPolygon)},
    {SIP_MLNAME_CAST(sipName_toFillPolygons), meth_QPainterPath_toFillPolygons, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_toFillPolygons)},
    {SIP_MLNAME_CAST(sipName_toReversed), meth_QPainterPath_toReversed, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_toReversed)},
    {SIP_MLNAME_CAST(sipName_toSubpathPolygons), meth_QPainterPath_toSubpathPolygons, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_toSubpathPolygons)},
    {SIP_MLNAME_CAST(sipName_translate), meth_QPainterPath_translate, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_translate)},
    {SIP_MLNAME_CAST(sipName_translated), meth_QPainterPath_translated, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_translated)},
    {SIP_MLNAME_CAST(sipName_united), meth_QPainterPath_united, METH_VARARGS, SIP_MLDOC_CAST(doc_QPainterPath_united)}
};

static sipEnumMemberDef enummembers_QPainterPath[] = {
    {sipName_CurveToDataElement, static_cast<int>( ::QPainterPath::CurveToDataElement), 219},
    {sipName_CurveToElement, static_cast<int>( ::QPainterPath::CurveToElement), 219},
    {sipName_LineToElement, static_cast<int>( ::QPainterPath::LineToElement), 219},
    {sipName_MoveToElement, static_cast<int>( ::QPainterPath::MoveToElement), 219},
};

PyDoc_STRVAR(doc_QPainterPath, "\1QPainterPath()\n"
"QPainterPath(Union[QPointF, QPoint])\n"
"QPainterPath(QPainterPath)");


static pyqt5ClassPluginDef plugin_QPainterPath = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtGui_QPainterPath = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QPainterPath,
        {SIP_NULLPTR},
        &plugin_QPainterPath
    },
    {
        sipNameNr_QPainterPath,
        {0, 0, 1},
        45, methods_QPainterPath,
        4, enummembers_QPainterPath,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QPainterPath,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QPainterPath,
    init_type_QPainterPath,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QPainterPath,
    assign_QPainterPath,
    array_QPainterPath,
    copy_QPainterPath,
    release_QPainterPath,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
